@@ -31,7 +31,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw();
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 sub pool(@)
 {
@@ -433,7 +433,7 @@ Example:
         undef $guard;       # unlock mutex
     });
 
-The callback receives a guard (see L<AnyEvent::Util::guard>) which unlocks the
+The callback receives a guard (see L<AnyEvent::Util#guard>) which unlocks the
 mutex. Hold the guard while You need locked resourse.
 
 =head3 is_locked
@@ -465,6 +465,13 @@ There may be only one write process that catches the lock.
 
 Both callbacks receive a guard to hold the mutex locked.
 
+
+=head3 rlock_limit(NUMBER)
+
+Get/Set count limit for rlock. If an rlock request is come and this limit
+is reached the request will be queued.
+
+
 =head3 is_locked
 
 Returns B<TRUE> if the mutex has 'read' or 'write' lock status.
